Third-Party Licenses

Torsten depends on a number of open-source Rust crates. This page documents all third-party dependencies and their license terms.

Total dependencies: 393

License Summary

LicenseCount
MIT OR Apache-2.0205
MIT71
Apache-2.0 OR MIT33
Unicode-3.018
Apache-2.017
Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT14
Unlicense OR MIT6
BSD-3-Clause4
Apache-2.0 OR ISC OR MIT2
MIT OR Apache-2.0 OR Zlib2
BlueOak-1.0.02
ISC2
CC0-1.02
BSD-2-Clause OR Apache-2.0 OR MIT2
BSD-2-Clause1
CC0-1.0 OR Apache-2.0 OR Apache-2.0 WITH LLVM-exception1
CC0-1.0 OR MIT-0 OR Apache-2.01
MIT OR Apache-2.0 OR BSD-1-Clause1
Apache-2.0 OR MIT1
Zlib1
MIT OR Apache-2.0 OR LGPL-2.1-or-later1
Apache-2.0 AND ISC1
Apache-2.0 OR BSL-1.01
Zlib OR Apache-2.0 OR MIT1
(MIT OR Apache-2.0) AND Unicode-3.01
Unknown1
CDLA-Permissive-2.01

Key Dependencies

These are the primary libraries that Torsten directly depends on:

CrateVersionLicenseDescription
pallas-codec1.0.0-alpha.5Apache-2.0Pallas common CBOR encoding interface and utilities
pallas-crypto1.0.0-alpha.5Apache-2.0Cryptographic primitives for Cardano
pallas-primitives1.0.0-alpha.5Apache-2.0Ledger primitives and cbor codec for the different Cardano eras
pallas-traverse1.0.0-alpha.5Apache-2.0Utilities to traverse over multi-era block data
pallas-addresses1.0.0-alpha.5Apache-2.0Ergonomic library to work with different Cardano addresses
pallas-network1.0.0-alpha.5Apache-2.0Ouroboros networking stack using async IO
uplc1.1.21Apache-2.0Utilities for working with Untyped Plutus Core
tokio1.50.0MITAn event-driven, non-blocking I/O platform for writing asynchronous I/O
backe...
hyper1.8.1MITA protective and efficient HTTP library for all.
reqwest0.12.28MIT OR Apache-2.0higher level HTTP client library
clap4.6.0MIT OR Apache-2.0A simple to use, efficient, and full-featured Command Line Argument Parser
serde1.0.228MIT OR Apache-2.0A generic serialization/deserialization framework
serde_json1.0.149MIT OR Apache-2.0A JSON serialization file format
bincode1.3.3MITA binary serialization / deserialization strategy that uses Serde for transfo...
blake2b_simd1.0.4MITa pure Rust BLAKE2b implementation with dynamic SIMD
sha20.9.9MIT OR Apache-2.0Pure Rust implementation of the SHA-2 hash function family
including SHA-224,...
ed25519-dalek2.2.0BSD-3-ClauseFast and efficient ed25519 EdDSA key generations, signing, and verification i...
curve25519-dalek4.1.3BSD-3-ClauseA pure-Rust implementation of group operations on ristretto255 and Curve25519
blst0.3.16Apache-2.0Bindings for blst BLS12-381 library
k2560.13.4Apache-2.0 OR MITsecp256k1 elliptic curve library written in pure Rust with support for ECDSA
...
minicbor0.26.5BlueOak-1.0.0A small CBOR codec suitable for no_std environments.
tracing0.1.44MITApplication-level tracing for Rust.
tracing-subscriber0.3.22MITUtilities for implementing and composing tracing subscribers.
dashmap6.1.0MITBlazing fast concurrent HashMap for Rust.
crossbeam0.8.4MIT OR Apache-2.0Tools for concurrent programming
dashu-int0.4.1MIT OR Apache-2.0A big integer library with good performance
memmap20.9.10MIT OR Apache-2.0Cross-platform Rust API for memory-mapped file IO
lz41.28.1MITRust LZ4 bindings library.
zstd0.13.3MITBinding for the zstd compression library.
tar0.4.44MIT OR Apache-2.0A Rust implementation of a TAR file reader and writer. This library does not
...
crc32fast1.5.0MIT OR Apache-2.0Fast, SIMD-accelerated CRC32 (IEEE) checksum computation
hex0.4.3MIT OR Apache-2.0Encoding and decoding data into/from hexadecimal representation.
bs580.5.1MIT/Apache-2.0Another Base58 codec implementation.
bech320.9.1MITEncodes and decodes the Bech32 format
base640.22.1MIT OR Apache-2.0encodes and decodes base64 as bytes or utf8
rand0.9.2MIT OR Apache-2.0Random number generators and other randomness functionality.
chrono0.4.44MIT OR Apache-2.0Date and time library for Rust
uuid1.22.0Apache-2.0 OR MITA library to generate and parse UUIDs.
indicatif0.17.11MITA progress bar and cli reporting library for Rust
vrf_dalek0.1.0Unknown

All Dependencies

Complete list of all third-party crates used by Torsten, sorted alphabetically.

CrateVersionLicense
aho-corasick1.1.4Unlicense OR MIT
android_system_properties0.1.5MIT/Apache-2.0
anes0.1.6MIT OR Apache-2.0
anstream1.0.0MIT OR Apache-2.0
anstyle1.0.13MIT OR Apache-2.0
anstyle-parse1.0.0MIT OR Apache-2.0
anstyle-query1.1.5MIT OR Apache-2.0
anstyle-wincon3.0.11MIT OR Apache-2.0
anyhow1.0.102MIT OR Apache-2.0
arrayref0.3.9BSD-2-Clause
arrayvec0.7.6MIT OR Apache-2.0
async-trait0.1.89MIT OR Apache-2.0
atomic-waker1.1.2Apache-2.0 OR MIT
autocfg1.5.0Apache-2.0 OR MIT
base16ct0.2.0Apache-2.0 OR MIT
base580.2.0MIT
base640.22.1MIT OR Apache-2.0
base64ct1.8.3Apache-2.0 OR MIT
bech320.9.1MIT
bincode1.3.3MIT
bit-set0.8.0Apache-2.0 OR MIT
bit-vec0.8.0Apache-2.0 OR MIT
bitflags2.11.0MIT OR Apache-2.0
bitvec1.0.1MIT
blake20.10.6MIT OR Apache-2.0
blake2b_simd1.0.4MIT
blake31.8.3CC0-1.0 OR Apache-2.0 OR Apache-2.0 WITH LLVM-exception
block-buffer0.9.0MIT OR Apache-2.0
blst0.3.16Apache-2.0
bs580.5.1MIT/Apache-2.0
bumpalo3.20.2MIT OR Apache-2.0
byteorder1.5.0Unlicense OR MIT
bytes1.11.1MIT
cast0.3.0MIT OR Apache-2.0
cc1.2.56MIT OR Apache-2.0
cfg-if1.0.4MIT OR Apache-2.0
cfg_aliases0.2.1MIT
chrono0.4.44MIT OR Apache-2.0
ciborium0.2.2Apache-2.0
ciborium-io0.2.2Apache-2.0
ciborium-ll0.2.2Apache-2.0
clap4.6.0MIT OR Apache-2.0
clap_builder4.6.0MIT OR Apache-2.0
clap_derive4.6.0MIT OR Apache-2.0
clap_lex1.1.0MIT OR Apache-2.0
colorchoice1.0.4MIT OR Apache-2.0
console0.15.11MIT
const-oid0.9.6Apache-2.0 OR MIT
constant_time_eq0.4.2CC0-1.0 OR MIT-0 OR Apache-2.0
core-foundation-sys0.8.7MIT OR Apache-2.0
cpufeatures0.2.17MIT OR Apache-2.0
crc3.4.0MIT OR Apache-2.0
crc-catalog2.4.0MIT OR Apache-2.0
crc32fast1.5.0MIT OR Apache-2.0
criterion0.5.1Apache-2.0 OR MIT
criterion-plot0.5.0MIT/Apache-2.0
crossbeam0.8.4MIT OR Apache-2.0
crossbeam-channel0.5.15MIT OR Apache-2.0
crossbeam-deque0.8.6MIT OR Apache-2.0
crossbeam-epoch0.9.18MIT OR Apache-2.0
crossbeam-queue0.3.12MIT OR Apache-2.0
crossbeam-utils0.8.21MIT OR Apache-2.0
crunchy0.2.4MIT
crypto-bigint0.5.5Apache-2.0 OR MIT
crypto-common0.1.7MIT OR Apache-2.0
cryptoxide0.4.4MIT/Apache-2.0
curve25519-dalek4.1.3BSD-3-Clause
curve25519-dalek-derive0.1.1MIT/Apache-2.0
darling0.21.3MIT
darling_core0.21.3MIT
darling_macro0.21.3MIT
dashmap6.1.0MIT
dashu-base0.4.1MIT OR Apache-2.0
dashu-int0.4.1MIT OR Apache-2.0
der0.7.10Apache-2.0 OR MIT
deranged0.5.8MIT OR Apache-2.0
derive_more1.0.0MIT
derive_more-impl1.0.0MIT
digest0.9.0MIT OR Apache-2.0
displaydoc0.2.5MIT OR Apache-2.0
dyn-clone1.0.20MIT OR Apache-2.0
ecdsa0.16.9Apache-2.0 OR MIT
ed255192.2.3Apache-2.0 OR MIT
ed25519-dalek2.2.0BSD-3-Clause
either1.15.0MIT OR Apache-2.0
elliptic-curve0.13.8Apache-2.0 OR MIT
encode_unicode1.0.0Apache-2.0 OR MIT
equivalent1.0.2Apache-2.0 OR MIT
errno0.3.14MIT OR Apache-2.0
fastrand2.3.0Apache-2.0 OR MIT
ff0.13.1MIT/Apache-2.0
fiat-crypto0.2.9MIT OR Apache-2.0 OR BSD-1-Clause
filetime0.2.27MIT/Apache-2.0
find-msvc-tools0.1.9MIT OR Apache-2.0
fnv1.0.7Apache-2.0 / MIT
foldhash0.1.5Zlib
form_urlencoded1.2.2MIT OR Apache-2.0
fs20.4.3MIT/Apache-2.0
funty2.0.0MIT
futures0.3.32MIT OR Apache-2.0
futures-channel0.3.32MIT OR Apache-2.0
futures-core0.3.32MIT OR Apache-2.0
futures-executor0.3.32MIT OR Apache-2.0
futures-io0.3.32MIT OR Apache-2.0
futures-macro0.3.32MIT OR Apache-2.0
futures-sink0.3.32MIT OR Apache-2.0
futures-task0.3.32MIT OR Apache-2.0
futures-util0.3.32MIT OR Apache-2.0
generic-array0.14.7MIT
getrandom0.4.2MIT OR Apache-2.0
glob0.3.3MIT OR Apache-2.0
group0.13.0MIT/Apache-2.0
half2.7.1MIT OR Apache-2.0
hamming0.1.3MIT/Apache-2.0
hashbrown0.16.1MIT OR Apache-2.0
heck0.5.0MIT OR Apache-2.0
hermit-abi0.5.2MIT OR Apache-2.0
hex0.4.3MIT OR Apache-2.0
hmac0.12.1MIT OR Apache-2.0
hostname0.3.1MIT
http1.4.0MIT OR Apache-2.0
http-body1.0.1MIT
http-body-util0.1.3MIT
httparse1.10.1MIT OR Apache-2.0
hyper1.8.1MIT
hyper-rustls0.27.7Apache-2.0 OR ISC OR MIT
hyper-util0.1.20MIT
iana-time-zone0.1.65MIT OR Apache-2.0
iana-time-zone-haiku0.1.2MIT OR Apache-2.0
icu_collections2.1.1Unicode-3.0
icu_locale_core2.1.1Unicode-3.0
icu_normalizer2.1.1Unicode-3.0
icu_normalizer_data2.1.1Unicode-3.0
icu_properties2.1.2Unicode-3.0
icu_properties_data2.1.2Unicode-3.0
icu_provider2.1.1Unicode-3.0
id-arena2.3.0MIT/Apache-2.0
ident_case1.0.1MIT/Apache-2.0
idna1.1.0MIT OR Apache-2.0
idna_adapter1.2.1Apache-2.0 OR MIT
indexmap2.13.0Apache-2.0 OR MIT
indicatif0.17.11MIT
ipnet2.12.0MIT OR Apache-2.0
iri-string0.7.10MIT OR Apache-2.0
is-terminal0.4.17MIT
is_terminal_polyfill1.70.2MIT OR Apache-2.0
itertools0.13.0MIT OR Apache-2.0
itoa1.0.17MIT OR Apache-2.0
jobserver0.1.34MIT OR Apache-2.0
js-sys0.3.91MIT OR Apache-2.0
k2560.13.4Apache-2.0 OR MIT
lazy_static1.5.0MIT OR Apache-2.0
leb128fmt0.1.0MIT OR Apache-2.0
libc0.2.183MIT OR Apache-2.0
libredox0.1.14MIT
linux-raw-sys0.12.1Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
litemap0.8.1Unicode-3.0
lock_api0.4.14MIT OR Apache-2.0
log0.4.29MIT OR Apache-2.0
lru-slab0.1.2MIT OR Apache-2.0 OR Zlib
lz41.28.1MIT
lz4-sys1.11.1+lz4-1.10.0MIT
match_cfg0.1.0MIT/Apache-2.0
matchers0.2.0MIT
memchr2.8.0Unlicense OR MIT
memmap20.9.10MIT OR Apache-2.0
miette5.10.0Apache-2.0
miette-derive5.10.0Apache-2.0
minicbor0.26.5BlueOak-1.0.0
minicbor-derive0.16.2BlueOak-1.0.0
mio1.1.1MIT
nu-ansi-term0.50.3MIT
num-bigint0.4.6MIT OR Apache-2.0
num-conv0.2.0MIT OR Apache-2.0
num-integer0.1.46MIT OR Apache-2.0
num-modular0.6.1Apache-2.0
num-order1.2.0Apache-2.0
num-rational0.4.2MIT OR Apache-2.0
num-traits0.2.19MIT OR Apache-2.0
num_cpus1.17.0MIT OR Apache-2.0
number_prefix0.4.0MIT
once_cell1.21.4MIT OR Apache-2.0
once_cell_polyfill1.70.2MIT OR Apache-2.0
oorandom11.1.5MIT
opaque-debug0.3.1MIT OR Apache-2.0
pallas-addresses1.0.0-alpha.5Apache-2.0
pallas-codec1.0.0-alpha.5Apache-2.0
pallas-crypto1.0.0-alpha.5Apache-2.0
pallas-network1.0.0-alpha.5Apache-2.0
pallas-primitives1.0.0-alpha.5Apache-2.0
pallas-traverse1.0.0-alpha.5Apache-2.0
parking_lot0.12.5MIT OR Apache-2.0
parking_lot_core0.9.12MIT OR Apache-2.0
paste1.0.15MIT OR Apache-2.0
peg0.8.5MIT
peg-macros0.8.5MIT
peg-runtime0.8.5MIT
percent-encoding2.3.2MIT OR Apache-2.0
pin-project-lite0.2.17Apache-2.0 OR MIT
pin-utils0.1.0MIT OR Apache-2.0
pkcs80.10.2Apache-2.0 OR MIT
pkg-config0.3.32MIT OR Apache-2.0
plain0.2.3MIT/Apache-2.0
plotters0.3.7MIT
plotters-backend0.3.7MIT
plotters-svg0.3.7MIT
portable-atomic1.13.1Apache-2.0 OR MIT
potential_utf0.1.4Unicode-3.0
powerfmt0.2.0MIT OR Apache-2.0
ppv-lite860.2.21MIT OR Apache-2.0
pretty0.11.3MIT
prettyplease0.2.37MIT OR Apache-2.0
proc-macro21.0.106MIT OR Apache-2.0
proptest1.10.0MIT OR Apache-2.0
quick-error1.2.3MIT/Apache-2.0
quinn0.11.9MIT OR Apache-2.0
quinn-proto0.11.14MIT OR Apache-2.0
quinn-udp0.5.14MIT OR Apache-2.0
quote1.0.45MIT OR Apache-2.0
r-efi6.0.0MIT OR Apache-2.0 OR LGPL-2.1-or-later
radium0.7.0MIT
rand0.9.2MIT OR Apache-2.0
rand_chacha0.9.0MIT OR Apache-2.0
rand_core0.9.5MIT OR Apache-2.0
rand_xorshift0.4.0MIT OR Apache-2.0
rayon1.11.0MIT OR Apache-2.0
rayon-core1.13.0MIT OR Apache-2.0
redox_syscall0.7.3MIT
ref-cast1.0.25MIT OR Apache-2.0
ref-cast-impl1.0.25MIT OR Apache-2.0
regex1.12.3MIT OR Apache-2.0
regex-automata0.4.14MIT OR Apache-2.0
regex-syntax0.8.10MIT OR Apache-2.0
reqwest0.12.28MIT OR Apache-2.0
rfc69790.4.0Apache-2.0 OR MIT
ring0.17.14Apache-2.0 AND ISC
rustc-hash2.1.1Apache-2.0 OR MIT
rustc_version0.4.1MIT OR Apache-2.0
rustix1.1.4Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
rustls0.23.37Apache-2.0 OR ISC OR MIT
rustls-pki-types1.14.0MIT OR Apache-2.0
rustls-webpki0.103.9ISC
rustversion1.0.22MIT OR Apache-2.0
rusty-fork0.3.1MIT/Apache-2.0
ryu1.0.23Apache-2.0 OR BSL-1.0
same-file1.0.6Unlicense/MIT
schemars1.2.1MIT
scopeguard1.2.0MIT OR Apache-2.0
sec10.7.3Apache-2.0 OR MIT
secp256k10.26.0CC0-1.0
secp256k1-sys0.8.2CC0-1.0
semver1.0.27MIT OR Apache-2.0
serde1.0.228MIT OR Apache-2.0
serde_core1.0.228MIT OR Apache-2.0
serde_derive1.0.228MIT OR Apache-2.0
serde_json1.0.149MIT OR Apache-2.0
serde_spanned0.6.9MIT OR Apache-2.0
serde_urlencoded0.7.1MIT/Apache-2.0
serde_with3.17.0MIT OR Apache-2.0
serde_with_macros3.17.0MIT OR Apache-2.0
sha20.9.9MIT OR Apache-2.0
sharded-slab0.1.7MIT
shlex1.3.0MIT OR Apache-2.0
signal-hook-registry1.4.8MIT OR Apache-2.0
signature2.2.0Apache-2.0 OR MIT
slab0.4.12MIT
smallvec1.15.1MIT OR Apache-2.0
snap1.1.1BSD-3-Clause
socket20.6.3MIT OR Apache-2.0
spki0.7.3Apache-2.0 OR MIT
stable_deref_trait1.2.1MIT OR Apache-2.0
static_assertions1.1.0MIT OR Apache-2.0
strsim0.11.1MIT
strum0.26.3MIT
strum_macros0.26.4MIT
subtle2.6.1BSD-3-Clause
syn2.0.117MIT OR Apache-2.0
sync_wrapper1.0.2Apache-2.0
synstructure0.13.2MIT
tap1.0.1MIT
tar0.4.44MIT OR Apache-2.0
tempfile3.27.0MIT OR Apache-2.0
thiserror2.0.18MIT OR Apache-2.0
thiserror-impl2.0.18MIT OR Apache-2.0
thread_local1.1.9MIT OR Apache-2.0
threadpool1.8.1MIT/Apache-2.0
time0.3.47MIT OR Apache-2.0
time-core0.1.8MIT OR Apache-2.0
time-macros0.2.27MIT OR Apache-2.0
tinystr0.8.2Unicode-3.0
tinytemplate1.2.1Apache-2.0 OR MIT
tinyvec1.10.0Zlib OR Apache-2.0 OR MIT
tinyvec_macros0.1.1MIT OR Apache-2.0 OR Zlib
tokio1.50.0MIT
tokio-macros2.6.1MIT
tokio-rustls0.26.4MIT OR Apache-2.0
tokio-util0.7.18MIT
toml0.8.23MIT OR Apache-2.0
toml_datetime0.6.11MIT OR Apache-2.0
toml_edit0.22.27MIT OR Apache-2.0
toml_write0.1.2MIT OR Apache-2.0
tower0.5.3MIT
tower-http0.6.8MIT
tower-layer0.3.3MIT
tower-service0.3.3MIT
tracing0.1.44MIT
tracing-appender0.2.4MIT
tracing-attributes0.1.31MIT
tracing-core0.1.36MIT
tracing-log0.2.0MIT
tracing-serde0.2.0MIT
tracing-subscriber0.3.22MIT
try-lock0.2.5MIT
typed-arena2.0.2MIT
typenum1.19.0MIT OR Apache-2.0
unarray0.1.4MIT OR Apache-2.0
unicode-ident1.0.24(MIT OR Apache-2.0) AND Unicode-3.0
unicode-segmentation1.12.0MIT OR Apache-2.0
unicode-width0.2.2MIT OR Apache-2.0
unicode-xid0.2.6MIT OR Apache-2.0
untrusted0.9.0ISC
uplc1.1.21Apache-2.0
url2.5.8MIT OR Apache-2.0
utf8_iter1.0.4Apache-2.0 OR MIT
utf8parse0.2.2Apache-2.0 OR MIT
uuid1.22.0Apache-2.0 OR MIT
valuable0.1.1MIT
version_check0.9.5MIT/Apache-2.0
vrf_dalek0.1.0Unknown
wait-timeout0.2.1MIT/Apache-2.0
walkdir2.5.0Unlicense/MIT
want0.3.1MIT
wasi0.9.0+wasi-snapshot-preview1Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
wasip21.0.2+wasi-0.2.9Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
wasip30.4.0+wasi-0.3.0-rc-2026-01-06Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
wasm-bindgen0.2.114MIT OR Apache-2.0
wasm-bindgen-futures0.4.64MIT OR Apache-2.0
wasm-bindgen-macro0.2.114MIT OR Apache-2.0
wasm-bindgen-macro-support0.2.114MIT OR Apache-2.0
wasm-bindgen-shared0.2.114MIT OR Apache-2.0
wasm-encoder0.244.0Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
wasm-metadata0.244.0Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
wasm-streams0.4.2MIT OR Apache-2.0
wasmparser0.244.0Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
web-sys0.3.91MIT OR Apache-2.0
web-time1.1.0MIT OR Apache-2.0
webpki-roots1.0.6CDLA-Permissive-2.0
winapi0.3.9MIT/Apache-2.0
winapi-i686-pc-windows-gnu0.4.0MIT/Apache-2.0
winapi-util0.1.11Unlicense OR MIT
winapi-x86_64-pc-windows-gnu0.4.0MIT/Apache-2.0
windows-core0.62.2MIT OR Apache-2.0
windows-implement0.60.2MIT OR Apache-2.0
windows-interface0.59.3MIT OR Apache-2.0
windows-link0.2.1MIT OR Apache-2.0
windows-result0.4.1MIT OR Apache-2.0
windows-strings0.5.1MIT OR Apache-2.0
windows-sys0.61.2MIT OR Apache-2.0
windows-targets0.53.5MIT OR Apache-2.0
windows_aarch64_gnullvm0.53.1MIT OR Apache-2.0
windows_aarch64_msvc0.53.1MIT OR Apache-2.0
windows_i686_gnu0.53.1MIT OR Apache-2.0
windows_i686_gnullvm0.53.1MIT OR Apache-2.0
windows_i686_msvc0.53.1MIT OR Apache-2.0
windows_x86_64_gnu0.53.1MIT OR Apache-2.0
windows_x86_64_gnullvm0.53.1MIT OR Apache-2.0
windows_x86_64_msvc0.53.1MIT OR Apache-2.0
winnow0.7.15MIT
wit-bindgen0.51.0Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
wit-bindgen-core0.51.0Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
wit-bindgen-rust0.51.0Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
wit-bindgen-rust-macro0.51.0Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
wit-component0.244.0Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
wit-parser0.244.0Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT
writeable0.6.2Unicode-3.0
wyz0.5.1MIT
xattr1.6.1MIT OR Apache-2.0
yoke0.8.1Unicode-3.0
yoke-derive0.8.1Unicode-3.0
zerocopy0.8.42BSD-2-Clause OR Apache-2.0 OR MIT
zerocopy-derive0.8.42BSD-2-Clause OR Apache-2.0 OR MIT
zerofrom0.1.6Unicode-3.0
zerofrom-derive0.1.6Unicode-3.0
zeroize1.8.2Apache-2.0 OR MIT
zeroize_derive1.4.3Apache-2.0 OR MIT
zerotrie0.2.3Unicode-3.0
zerovec0.11.5Unicode-3.0
zerovec-derive0.11.2Unicode-3.0
zmij1.0.21MIT
zstd0.13.3MIT
zstd-safe7.2.4MIT OR Apache-2.0
zstd-sys2.0.16+zstd.1.5.7MIT/Apache-2.0

Regenerating This Page

This page is generated from Cargo.lock metadata. To regenerate after dependency changes:

python3 scripts/generate-licenses.py > docs/src/reference/third-party-licenses.md